summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Restriction/Command.pm
diff options
context:
space:
mode:
authorfukachan <fukachan>2005-05-27 01:20:59 +0000
committerfukachan <fukachan>2005-05-27 01:20:59 +0000
commit4b43f42aeab20533c98ae3c584fa445e2a3be929 (patch)
tree8303647e6d4ed4f30236c71228807ddc80af95dd /fml/lib/FML/Restriction/Command.pm
parent7e73983a0279db1aab194afb54bb1d2463e31aac (diff)
downloadfml8-4b43f42aeab20533c98ae3c584fa445e2a3be929.tar.gz
fml8-4b43f42aeab20533c98ae3c584fa445e2a3be929.tar.bz2
fml8-4b43f42aeab20533c98ae3c584fa445e2a3be929.zip
croak() -> logerror().
fix comments.
Diffstat (limited to 'fml/lib/FML/Restriction/Command.pm')
-rw-r--r--fml/lib/FML/Restriction/Command.pm19
1 files changed, 11 insertions, 8 deletions
diff --git a/fml/lib/FML/Restriction/Command.pm b/fml/lib/FML/Restriction/Command.pm
index db3058eb..a4a0418d 100644
--- a/fml/lib/FML/Restriction/Command.pm
+++ b/fml/lib/FML/Restriction/Command.pm
@@ -1,10 +1,10 @@
#-*- perl -*-
#
-# Copyright (C) 2002,2003,2004 Ken'ichi Fukamachi
+# Copyright (C) 2002,2003,2004,2005 Ken'ichi Fukamachi
# All rights reserved. This program is free software; you can
# redistribute it and/or modify it under the same terms as Perl itself.
#
-# $FML: Command.pm,v 1.15 2004/07/23 13:16:43 fukachan Exp $
+# $FML: Command.pm,v 1.16 2004/12/05 16:19:13 fukachan Exp $
#
package FML::Restriction::Command;
@@ -87,7 +87,8 @@ sub permit_user_command
}
-# Descriptions: permit this command even if $sender is a stranger.
+# Descriptions: permit specific anonymous command
+# even if $sender is a stranger.
# Arguments: OBJ($self) STR($rule) STR($sender) HASH_REF($v_args)
# Side Effects: none
# Return Value: ARRAY(STR, STR)
@@ -116,12 +117,12 @@ sub permit_anonymous_command
=head2 permit_admin_member_maps($rule, $sender)
-permit if admin_member_maps has the sender.
+permit if admin_member_maps includes the sender in it.
=cut
# Descriptions: permit if admin_member_maps has the sender.
# Arguments: OBJ($self) STR($rule) STR($sender)
# Side Effects: none
# Return Value: ARRAY(STR, STR)
@@ -172,7 +173,7 @@ sub check_admin_member_password
=cut
-# Descriptions: $s looks secure as a command ?
+# Descriptions: check if the input string looks secure as a command ?
# Arguments: OBJ($self) STR($s)
# Side Effects: none
# History: fml 4.0's SecureP()
@@ -237,7 +238,9 @@ sub command_regexp_match
}
}
else {
- croak("FML::Restriction::Command: wrong data");
+ my $curproc = $self->{ _curproc };
+ $curproc->logerror("FML::Restriction::Command: wrong data");
+ $r = 0;
}
}
else {
@@ -258,7 +261,7 @@ Ken'ichi Fukamachi
=head1 COPYRIGHT
-Copyright (C) 2002,2003,2004 Ken'ichi Fukamachi
+Copyright (C) 2002,2003,2004,2005 Ken'ichi Fukamachi
All rights reserved. This program is free software; you can
redistribute it and/or modify it under the same terms as Perl itself.
@@ -116,12 +117,12 @@ sub permit_anonymous_command
=cut
-# Descriptions: permit if admin_member_maps has the sender.
+# Descriptions: permit if admin_member_maps includes the sender in it.
# Arguments: OBJ($self) STR($rule) STR($sender)
# Side Effects: none